@@ -35,7 +35,7 @@ class CeleryRedisResultMonitor(object):
 
     def start(self):
         Thread(target=self._watch, name='result-monitor').start()
-        LOGGER.info(f'启动结果监听...')
+        LOGGER.info(f'启动Celery结果监听服务...')
 
     def _watch(self):
         # 当前：每个app一个结果监视器
@@ -56,6 +56,7 @@ class CeleryRedisResultMonitor(object):
                                 callback_func = callback.get('callback_func', None)
                                 callback_data = callback.get('callback_data', None)
                                 if callback_func:
+                                    # TODO 兼容线程与协程
                                     func = ref_to_obj(callback_func)
                                     thread_pool.submit(func, result, callback_data)
                                 else:
